@@ -4,7 +4,7 @@ from typing import List
 from marshmallow import fields
 from marshmallow.exceptions import ValidationError
 
-from ..utils.facet_helpers import searchable
+from ..utils.facet_helpers import facet_definition, facet_name
 from .datatypes import DataType, Import
 
 
@@ -51,15 +51,25 @@ class StringDataType(DataType):
 
         return validators
 
-    def facet(self, key, definition={}, props_num=None, create=True):
-        if not searchable(definition, create):
-            return False
-        key = definition.get("key", key)
-        field = definition.get("field", "TermsFacet(field = ")
-        facet_def = {"path": key, "class": field}
-        if "field" in definition:
-            facet_def["defined_class"] = True
-        return facet_def
+    def get_facet(self, stack, parent_path):
+        key, field = facet_definition(self)
+        path = parent_path
+        if len(parent_path) > 0 and self.key:
+            path = parent_path + "." + self.key
+        elif self.key:
+            path = self.key
+        if field:
+            return [{"facet": field, "path": facet_name(path)}]
+        else:
+            # TODO: we should use label from field's ui spec here
+            # ? why there is no label spec in self.definition["ui"]
+            label = path.replace(".", "/") + ".label"
+            return [
+                {
+                    "facet": f'TermsFacet(field="{path}", label=_("{label}") )',
+                    "path": facet_name(path),
+                }
+            ]
 
     @property
     def ui_marshmallow_field(self):
@@ -70,11 +80,8 @@ class StringDataType(DataType):
     def ui_marshmallow(self, **extras):
         ret = super().ui_marshmallow(**extras)
         if "enum" in self.definition:
-            gettext_prefix = (
-                self.definition.get("ui", {}).get("i18n-prefix")
-                or self.model.get("i18n-prefix")
-                or self.model.get("package")
-            )
+            # TODO: allow for custom prefix
+            gettext_prefix = self.model.get("package")
             ret.setdefault("arguments", []).extend(
                 [
                     f'value_prefix="{gettext_prefix}"',
@@ -99,8 +106,8 @@ class FulltextDataType(StringDataType):
     mapping_type = "text"
     model_type = "fulltext"
 
-    def facet(self, key, definition=None, props_num=None, create=True):
-        return False
+    def get_facet(self, stack, parent_path):
+        pass
 
 
 class KeywordDataType(StringDataType):
@@ -118,12 +125,28 @@ class FulltextKeywordDataType(StringDataType):
         mapping_el.setdefault("fields", {}).setdefault("keyword", {"type": "keyword"})
         return ret
 
-    def facet(self, key, definition={}, props_num=None, create=True):
-        if not searchable(definition, create):
-            return False
-        key = definition.get("key", key + "_keyword")
-        field = definition.get("field", "TermsFacet(field = ")
-        facet_def = {"path": key, "class": field}
-        if "field" in definition:
-            facet_def["defined_class"] = True
-        return facet_def
+    def get_facet(self, stack, parent_path):
+        key, field = facet_definition(self)
+        path = parent_path
+        if len(parent_path) > 0 and self.key:
+            path = parent_path + "." + self.key
+        elif self.key:
+            path = self.key
+        path = path + ".keyword"
+        if field:
+            return [{"facet": field, "path": facet_name(path)}]
+        else:
+            # TODO: we should use label from field's ui spec here
+            # ? why there is no label spec in self.definition["ui"]
+            label = path.replace(".", "/") + ".label"
+            return [
+                {
+                    "facet": f'TermsFacet(field="{path}", label=_("{label}") )',
+                    "path": facet_name(path),
+                }
+            ]
+
+
+class URLDataType(StringDataType):
+    mapping_type = "keyword"
+    model_type = "url"
