@@ -12,5 +12,6 @@ class InvenioVersionBuilder(PythonBuilder):
             "python", self.current_model.package_path / "version.py"
         )
         python_output.merge(
-            "invenio_version", {"settings": self.settings, "current_model": self.current_model}
+            "invenio_version",
+            {"settings": self.settings, "current_model": self.current_model},
         )
