@@ -21,16 +21,24 @@ class PropertyMarshmallowSchema(ExtendablePartSchema):
     validators = fields.List(fields.String(), required=False)
 
 
+class ExtraField(ma.Schema):
+    name = fields.String(required=True)
+    value = fields.String(required=True)
+
+
 class ModelMarshmallowSchema(ma.Schema):
     class ObjectOnlyMarshmallowProps(ExtendablePartSchema):
         imports = fields.List(
             fields.Nested(ImportSchema), required=False
         )  # imports must be here as well as it is used on model's root (without field)
         generate = fields.Boolean(required=False)
-        schema_class = fields.String(data_key="schema-class", required=False)
+        schema_class = fields.String(data_key="schema-class", required=False,allow_none=True)
         base_classes = fields.List(
             fields.String(), data_key="base-classes", required=False
         )
+        extra_fields = fields.List(
+            fields.Nested(ExtraField), required=False, data_key="extra-fields"
+        )
 
     marshmallow = fields.Nested(
         lambda: model_validator.validator_class("property-marshmallow-model")()
